@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #
 #
-#	dnsenum.pl VERSION 1.3.0
+#	dnsenum.pl VERSION 1.3.2
 #	This version:	- changed version number to the correct one
 #
 #	dnsenum.pl: multithread script to enumerate information on
@@ -50,9 +50,6 @@
 use strict;
 use warnings
   ; #it complains about uninitialized values when it doesn't find address in RR; need to fix later
-no
-  if $] >= 5.018, 'warnings',
-  "experimental::smartmatch";    # Mute Experimental Warning
 use Config;
 use Term::ANSIColor;
 use Getopt::Long;
@@ -86,7 +83,7 @@ my $string_gen  = String::Random->new;
 my $wildcards   = $string_gen->randpattern("cccccccccccc");
 my @wildcardaddress;
 my @wildcardcname;
-my $VERSION = '1.2.6';
+my $VERSION = '1.3.1';
 
 #load threads modules (perl must be compiled with ithreads support)
 BEGIN {
@@ -191,11 +188,6 @@ if ($threads) {
     }
 }
 
-if ( $whois && !defined $whois_support ) {
-    warn "Warning: can't load Net::Whois::IP module, "
-      . "whois queries disabled.\n";
-    $whois = undef;
-}
 if ( $whois && !defined $whois_support ) {
     warn "Warning: can't load Net::Whois::IP module, "
       . "whois queries disabled.\n";
@@ -746,9 +738,9 @@ sub nslookup {
                 ##we only print / add the result if it doesn't match the wildcardaddress
                 if (
                     !(
-                        $rr->can('address') && $rr->address ~~ @wildcardaddress
+                        $rr->can('address') && grep { $_ eq $rr->address } @wildcardaddress
                     )
-                    && !( $rr->name ~~ @wildcardcname )
+                    && !( grep { $_ eq $rr->name } @wildcardcname )
                   )
                 {
                     printrr( $rr->string );
@@ -1507,7 +1499,7 @@ dnsenum.pl -- multithread script to enumerate information on a domain and to dis
 
 =head1 VERSION
 
-dnsenum.pl version 1.3.0
+dnsenum.pl version 1.3.1
 
 =head1 SYNOPSIS
 
